from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.Haptics
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Win32.System.WinRT
class IKnownSimpleHapticsControllerWaveformsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics'
    _iid_ = Guid('{3d577ef7-4cee-11e6-b535-001bdc06ab3b}')
    @winrt_commethod(6)
    def get_Click(self) -> UInt16: ...
    @winrt_commethod(7)
    def get_BuzzContinuous(self) -> UInt16: ...
    @winrt_commethod(8)
    def get_RumbleContinuous(self) -> UInt16: ...
    @winrt_commethod(9)
    def get_Press(self) -> UInt16: ...
    @winrt_commethod(10)
    def get_Release(self) -> UInt16: ...
    BuzzContinuous = property(get_BuzzContinuous, None)
    Click = property(get_Click, None)
    Press = property(get_Press, None)
    Release = property(get_Release, None)
    RumbleContinuous = property(get_RumbleContinuous, None)
class IKnownSimpleHapticsControllerWaveformsStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics2'
    _iid_ = Guid('{a7d24c27-b79d-510a-bf79-ff6d49173e1d}')
    @winrt_commethod(6)
    def get_BrushContinuous(self) -> UInt16: ...
    @winrt_commethod(7)
    def get_ChiselMarkerContinuous(self) -> UInt16: ...
    @winrt_commethod(8)
    def get_EraserContinuous(self) -> UInt16: ...
    @winrt_commethod(9)
    def get_Error(self) -> UInt16: ...
    @winrt_commethod(10)
    def get_GalaxyPenContinuous(self) -> UInt16: ...
    @winrt_commethod(11)
    def get_Hover(self) -> UInt16: ...
    @winrt_commethod(12)
    def get_InkContinuous(self) -> UInt16: ...
    @winrt_commethod(13)
    def get_MarkerContinuous(self) -> UInt16: ...
    @winrt_commethod(14)
    def get_PencilContinuous(self) -> UInt16: ...
    @winrt_commethod(15)
    def get_Success(self) -> UInt16: ...
    BrushContinuous = property(get_BrushContinuous, None)
    ChiselMarkerContinuous = property(get_ChiselMarkerContinuous, None)
    EraserContinuous = property(get_EraserContinuous, None)
    Error = property(get_Error, None)
    GalaxyPenContinuous = property(get_GalaxyPenContinuous, None)
    Hover = property(get_Hover, None)
    InkContinuous = property(get_InkContinuous, None)
    MarkerContinuous = property(get_MarkerContinuous, None)
    PencilContinuous = property(get_PencilContinuous, None)
    Success = property(get_Success, None)
class ISimpleHapticsController(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Haptics.ISimpleHapticsController'
    _iid_ = Guid('{3d577ef9-4cee-11e6-b535-001bdc06ab3b}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_SupportedFeedback(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Haptics.SimpleHapticsControllerFeedback]: ...
    @winrt_commethod(8)
    def get_IsIntensitySupported(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_IsPlayCountSupported(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_IsPlayDurationSupported(self) -> Boolean: ...
    @winrt_commethod(11)
    def get_IsReplayPauseIntervalSupported(self) -> Boolean: ...
    @winrt_commethod(12)
    def StopFeedback(self) -> Void: ...
    @winrt_commethod(13)
    def SendHapticFeedback(self, feedback: win32more.Windows.Devices.Haptics.SimpleHapticsControllerFeedback) -> Void: ...
    @winrt_commethod(14)
    def SendHapticFeedbackWithIntensity(self, feedback: win32more.Windows.Devices.Haptics.SimpleHapticsControllerFeedback, intensity: Double) -> Void: ...
    @winrt_commethod(15)
    def SendHapticFeedbackForDuration(self, feedback: win32more.Windows.Devices.Haptics.SimpleHapticsControllerFeedback, intensity: Double, playDuration: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(16)
    def SendHapticFeedbackForPlayCount(self, feedback: win32more.Windows.Devices.Haptics.SimpleHapticsControllerFeedback, intensity: Double, playCount: Int32, replayPauseInterval: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    Id = property(get_Id, None)
    IsIntensitySupported = property(get_IsIntensitySupported, None)
    IsPlayCountSupported = property(get_IsPlayCountSupported, None)
    IsPlayDurationSupported = property(get_IsPlayDurationSupported, None)
    IsReplayPauseIntervalSupported = property(get_IsReplayPauseIntervalSupported, None)
    SupportedFeedback = property(get_SupportedFeedback, None)
class ISimpleHapticsControllerFeedback(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Haptics.ISimpleHapticsControllerFeedback'
    _iid_ = Guid('{3d577ef8-4cee-11e6-b535-001bdc06ab3b}')
    @winrt_commethod(6)
    def get_Waveform(self) -> UInt16: ...
    @winrt_commethod(7)
    def get_Duration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    Duration = property(get_Duration, None)
    Waveform = property(get_Waveform, None)
class IVibrationDevice(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Haptics.IVibrationDevice'
    _iid_ = Guid('{40f21a3e-8844-47ff-b312-06185a3844da}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_SimpleHapticsController(self) -> win32more.Windows.Devices.Haptics.SimpleHapticsController: ...
    Id = property(get_Id, None)
    SimpleHapticsController = property(get_SimpleHapticsController, None)
class IVibrationDeviceStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Haptics.IVibrationDeviceStatics'
    _iid_ = Guid('{53e2eded-2290-4ac9-8eb3-1a84122eb71c}')
    @winrt_commethod(6)
    def RequestAccessAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Haptics.VibrationAccessStatus]: ...
    @winrt_commethod(7)
    def GetDeviceSelector(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def FromIdAsync(self, deviceId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Haptics.VibrationDevice]: ...
    @winrt_commethod(9)
    def GetDefaultAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Haptics.VibrationDevice]: ...
    @winrt_commethod(10)
    def FindAllAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Haptics.VibrationDevice]]: ...
class _KnownSimpleHapticsControllerWaveforms_Meta_(ComPtr.__class__):
    pass
class KnownSimpleHapticsControllerWaveforms(ComPtr, metaclass=_KnownSimpleHapticsControllerWaveforms_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Haptics.KnownSimpleHapticsControllerWaveforms'
    @winrt_classmethod
    def get_BrushContinuous(cls: win32more.Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics2) -> UInt16: ...
    @winrt_classmethod
    def get_ChiselMarkerContinuous(cls: win32more.Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics2) -> UInt16: ...
    @winrt_classmethod
    def get_EraserContinuous(cls: win32more.Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics2) -> UInt16: ...
    @winrt_classmethod
    def get_Error(cls: win32more.Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics2) -> UInt16: ...
    @winrt_classmethod
    def get_GalaxyPenContinuous(cls: win32more.Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics2) -> UInt16: ...
    @winrt_classmethod
    def get_Hover(cls: win32more.Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics2) -> UInt16: ...
    @winrt_classmethod
    def get_InkContinuous(cls: win32more.Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics2) -> UInt16: ...
    @winrt_classmethod
    def get_MarkerContinuous(cls: win32more.Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics2) -> UInt16: ...
    @winrt_classmethod
    def get_PencilContinuous(cls: win32more.Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics2) -> UInt16: ...
    @winrt_classmethod
    def get_Success(cls: win32more.Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics2) -> UInt16: ...
    @winrt_classmethod
    def get_Click(cls: win32more.Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics) -> UInt16: ...
    @winrt_classmethod
    def get_BuzzContinuous(cls: win32more.Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics) -> UInt16: ...
    @winrt_classmethod
    def get_RumbleContinuous(cls: win32more.Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics) -> UInt16: ...
    @winrt_classmethod
    def get_Press(cls: win32more.Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics) -> UInt16: ...
    @winrt_classmethod
    def get_Release(cls: win32more.Windows.Devices.Haptics.IKnownSimpleHapticsControllerWaveformsStatics) -> UInt16: ...
    _KnownSimpleHapticsControllerWaveforms_Meta_.BrushContinuous = property(get_BrushContinuous, None)
    _KnownSimpleHapticsControllerWaveforms_Meta_.BuzzContinuous = property(get_BuzzContinuous, None)
    _KnownSimpleHapticsControllerWaveforms_Meta_.ChiselMarkerContinuous = property(get_ChiselMarkerContinuous, None)
    _KnownSimpleHapticsControllerWaveforms_Meta_.Click = property(get_Click, None)
    _KnownSimpleHapticsControllerWaveforms_Meta_.EraserContinuous = property(get_EraserContinuous, None)
    _KnownSimpleHapticsControllerWaveforms_Meta_.Error = property(get_Error, None)
    _KnownSimpleHapticsControllerWaveforms_Meta_.GalaxyPenContinuous = property(get_GalaxyPenContinuous, None)
    _KnownSimpleHapticsControllerWaveforms_Meta_.Hover = property(get_Hover, None)
    _KnownSimpleHapticsControllerWaveforms_Meta_.InkContinuous = property(get_InkContinuous, None)
    _KnownSimpleHapticsControllerWaveforms_Meta_.MarkerContinuous = property(get_MarkerContinuous, None)
    _KnownSimpleHapticsControllerWaveforms_Meta_.PencilContinuous = property(get_PencilContinuous, None)
    _KnownSimpleHapticsControllerWaveforms_Meta_.Press = property(get_Press, None)
    _KnownSimpleHapticsControllerWaveforms_Meta_.Release = property(get_Release, None)
    _KnownSimpleHapticsControllerWaveforms_Meta_.RumbleContinuous = property(get_RumbleContinuous, None)
    _KnownSimpleHapticsControllerWaveforms_Meta_.Success = property(get_Success, None)
class SimpleHapticsController(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Haptics.ISimpleHapticsController
    _classid_ = 'Windows.Devices.Haptics.SimpleHapticsController'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Devices.Haptics.ISimpleHapticsController) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_SupportedFeedback(self: win32more.Windows.Devices.Haptics.ISimpleHapticsController) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Haptics.SimpleHapticsControllerFeedback]: ...
    @winrt_mixinmethod
    def get_IsIntensitySupported(self: win32more.Windows.Devices.Haptics.ISimpleHapticsController) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsPlayCountSupported(self: win32more.Windows.Devices.Haptics.ISimpleHapticsController) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsPlayDurationSupported(self: win32more.Windows.Devices.Haptics.ISimpleHapticsController) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsReplayPauseIntervalSupported(self: win32more.Windows.Devices.Haptics.ISimpleHapticsController) -> Boolean: ...
    @winrt_mixinmethod
    def StopFeedback(self: win32more.Windows.Devices.Haptics.ISimpleHapticsController) -> Void: ...
    @winrt_mixinmethod
    def SendHapticFeedback(self: win32more.Windows.Devices.Haptics.ISimpleHapticsController, feedback: win32more.Windows.Devices.Haptics.SimpleHapticsControllerFeedback) -> Void: ...
    @winrt_mixinmethod
    def SendHapticFeedbackWithIntensity(self: win32more.Windows.Devices.Haptics.ISimpleHapticsController, feedback: win32more.Windows.Devices.Haptics.SimpleHapticsControllerFeedback, intensity: Double) -> Void: ...
    @winrt_mixinmethod
    def SendHapticFeedbackForDuration(self: win32more.Windows.Devices.Haptics.ISimpleHapticsController, feedback: win32more.Windows.Devices.Haptics.SimpleHapticsControllerFeedback, intensity: Double, playDuration: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def SendHapticFeedbackForPlayCount(self: win32more.Windows.Devices.Haptics.ISimpleHapticsController, feedback: win32more.Windows.Devices.Haptics.SimpleHapticsControllerFeedback, intensity: Double, playCount: Int32, replayPauseInterval: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    Id = property(get_Id, None)
    IsIntensitySupported = property(get_IsIntensitySupported, None)
    IsPlayCountSupported = property(get_IsPlayCountSupported, None)
    IsPlayDurationSupported = property(get_IsPlayDurationSupported, None)
    IsReplayPauseIntervalSupported = property(get_IsReplayPauseIntervalSupported, None)
    SupportedFeedback = property(get_SupportedFeedback, None)
class SimpleHapticsControllerFeedback(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Haptics.ISimpleHapticsControllerFeedback
    _classid_ = 'Windows.Devices.Haptics.SimpleHapticsControllerFeedback'
    @winrt_mixinmethod
    def get_Waveform(self: win32more.Windows.Devices.Haptics.ISimpleHapticsControllerFeedback) -> UInt16: ...
    @winrt_mixinmethod
    def get_Duration(self: win32more.Windows.Devices.Haptics.ISimpleHapticsControllerFeedback) -> win32more.Windows.Foundation.TimeSpan: ...
    Duration = property(get_Duration, None)
    Waveform = property(get_Waveform, None)
class VibrationAccessStatus(Enum, Int32):
    Allowed = 0
    DeniedByUser = 1
    DeniedBySystem = 2
    DeniedByEnergySaver = 3
class VibrationDevice(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Haptics.IVibrationDevice
    _classid_ = 'Windows.Devices.Haptics.VibrationDevice'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Devices.Haptics.IVibrationDevice) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_SimpleHapticsController(self: win32more.Windows.Devices.Haptics.IVibrationDevice) -> win32more.Windows.Devices.Haptics.SimpleHapticsController: ...
    @winrt_classmethod
    def RequestAccessAsync(cls: win32more.Windows.Devices.Haptics.IVibrationDeviceStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Haptics.VibrationAccessStatus]: ...
    @winrt_classmethod
    def GetDeviceSelector(cls: win32more.Windows.Devices.Haptics.IVibrationDeviceStatics) -> WinRT_String: ...
    @winrt_classmethod
    def FromIdAsync(cls: win32more.Windows.Devices.Haptics.IVibrationDeviceStatics, deviceId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Haptics.VibrationDevice]: ...
    @winrt_classmethod
    def GetDefaultAsync(cls: win32more.Windows.Devices.Haptics.IVibrationDeviceStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Haptics.VibrationDevice]: ...
    @winrt_classmethod
    def FindAllAsync(cls: win32more.Windows.Devices.Haptics.IVibrationDeviceStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Haptics.VibrationDevice]]: ...
    Id = property(get_Id, None)
    SimpleHapticsController = property(get_SimpleHapticsController, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.ExtendedExecution.Foreground
import win32more.Windows.Foundation
import win32more.Windows.Win32.System.WinRT
class ExtendedExecutionForegroundReason(Enum, Int32):
    Unspecified = 0
    SavingData = 1
    BackgroundAudio = 2
    Unconstrained = 3
class ExtendedExecutionForegroundResult(Enum, Int32):
    Allowed = 0
    Denied = 1
class ExtendedExecutionForegroundRevokedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.IExtendedExecutionForegroundRevokedEventArgs
    _classid_ = 'Windows.ApplicationModel.ExtendedExecution.Foreground.ExtendedExecutionForegroundRevokedEventArgs'
    @winrt_mixinmethod
    def get_Reason(self: win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.IExtendedExecutionForegroundRevokedEventArgs) -> win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.ExtendedExecutionForegroundRevokedReason: ...
    Reason = property(get_Reason, None)
class ExtendedExecutionForegroundRevokedReason(Enum, Int32):
    Resumed = 0
    SystemPolicy = 1
class ExtendedExecutionForegroundSession(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.IExtendedExecutionForegroundSession
    _classid_ = 'Windows.ApplicationModel.ExtendedExecution.Foreground.ExtendedExecutionForegroundSession'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.ExtendedExecutionForegroundSession.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.ExtendedExecutionForegroundSession: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.IExtendedExecutionForegroundSession) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.IExtendedExecutionForegroundSession, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def add_Revoked(self: win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.IExtendedExecutionForegroundSession, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Win32.System.WinRT.IInspectable, win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.ExtendedExecutionForegroundRevokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Revoked(self: win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.IExtendedExecutionForegroundSession, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def RequestExtensionAsync(self: win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.IExtendedExecutionForegroundSession) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.ExtendedExecutionForegroundResult]: ...
    @winrt_mixinmethod
    def get_Reason(self: win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.IExtendedExecutionForegroundSession) -> win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.ExtendedExecutionForegroundReason: ...
    @winrt_mixinmethod
    def put_Reason(self: win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.IExtendedExecutionForegroundSession, value: win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.ExtendedExecutionForegroundReason) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    Description = property(get_Description, put_Description)
    Reason = property(get_Reason, put_Reason)
    Revoked = event()
class IExtendedExecutionForegroundRevokedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.ExtendedExecution.Foreground.IExtendedExecutionForegroundRevokedEventArgs'
    _iid_ = Guid('{b07cd940-9557-aea4-2c99-bdd56d9be461}')
    @winrt_commethod(6)
    def get_Reason(self) -> win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.ExtendedExecutionForegroundRevokedReason: ...
    Reason = property(get_Reason, None)
class IExtendedExecutionForegroundSession(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.ApplicationModel.ExtendedExecution.Foreground.IExtendedExecutionForegroundSession'
    _iid_ = Guid('{fbf440e1-9d10-4201-b01e-c83275296f2e}')
    @winrt_commethod(6)
    def get_Description(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def add_Revoked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Win32.System.WinRT.IInspectable, win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.ExtendedExecutionForegroundRevokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_Revoked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def RequestExtensionAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.ExtendedExecutionForegroundResult]: ...
    @winrt_commethod(11)
    def get_Reason(self) -> win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.ExtendedExecutionForegroundReason: ...
    @winrt_commethod(12)
    def put_Reason(self, value: win32more.Windows.ApplicationModel.ExtendedExecution.Foreground.ExtendedExecutionForegroundReason) -> Void: ...
    Description = property(get_Description, put_Description)
    Reason = property(get_Reason, put_Reason)
    Revoked = event()


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Microsoft.Windows.Widgets.Notifications
import win32more.Windows.Foundation
import win32more.Windows.Win32.System.WinRT
class AnnouncementActionKind(Enum, Int32):
    Shown = 0
    Engaged = 1
class AnnouncementTextColor(Enum, Int32):
    Default = 0
    Dark = 1
    Light = 2
    Accent = 3
    Good = 4
    Warning = 5
    Attention = 6
class FeedAnnouncement(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement
    _classid_ = 'Microsoft.Windows.Widgets.Notifications.FeedAnnouncement'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 5:
            super().__init__(move=win32more.Microsoft.Windows.Widgets.Notifications.FeedAnnouncement.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncementFactory, id: WinRT_String, primaryText: WinRT_String, secondaryText: WinRT_String, lightModeIcon: win32more.Windows.Foundation.Uri, darkModeIcon: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.Widgets.Notifications.FeedAnnouncement: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Id(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_PrimaryText(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PrimaryText(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SecondaryText(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SecondaryText(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_LightModeIconUri(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_LightModeIconUri(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_DarkModeIconUri(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_DarkModeIconUri(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_PrimaryTextColor(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementTextColor: ...
    @winrt_mixinmethod
    def put_PrimaryTextColor(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementTextColor) -> Void: ...
    @winrt_mixinmethod
    def get_SecondaryTextColor(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementTextColor: ...
    @winrt_mixinmethod
    def put_SecondaryTextColor(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementTextColor) -> Void: ...
    @winrt_mixinmethod
    def get_CustomAccessibilityText(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_CustomAccessibilityText(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IsSecondaryTextSubtle(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSecondaryTextSubtle(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ShowBadgeIfUserNotEngaged(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShowBadgeIfUserNotEngaged(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ExpirationTime(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_ExpirationTime(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_Duration(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_Duration(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    CustomAccessibilityText = property(get_CustomAccessibilityText, put_CustomAccessibilityText)
    DarkModeIconUri = property(get_DarkModeIconUri, put_DarkModeIconUri)
    Duration = property(get_Duration, put_Duration)
    ExpirationTime = property(get_ExpirationTime, put_ExpirationTime)
    Id = property(get_Id, put_Id)
    IsSecondaryTextSubtle = property(get_IsSecondaryTextSubtle, put_IsSecondaryTextSubtle)
    LightModeIconUri = property(get_LightModeIconUri, put_LightModeIconUri)
    PrimaryText = property(get_PrimaryText, put_PrimaryText)
    PrimaryTextColor = property(get_PrimaryTextColor, put_PrimaryTextColor)
    SecondaryText = property(get_SecondaryText, put_SecondaryText)
    SecondaryTextColor = property(get_SecondaryTextColor, put_SecondaryTextColor)
    ShowBadgeIfUserNotEngaged = property(get_ShowBadgeIfUserNotEngaged, put_ShowBadgeIfUserNotEngaged)
class FeedAnnouncementInvokedArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncementInvokedArgs
    _classid_ = 'Microsoft.Windows.Widgets.Notifications.FeedAnnouncementInvokedArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncementInvokedArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_FeedDefinitionId(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncementInvokedArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AnnouncementId(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncementInvokedArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ActionKind(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncementInvokedArgs) -> win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementActionKind: ...
    ActionKind = property(get_ActionKind, None)
    AnnouncementId = property(get_AnnouncementId, None)
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class IFeedAnnouncement(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement'
    _iid_ = Guid('{b88e8c2c-d251-5344-acc2-8cf9ba07ec15}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Id(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_PrimaryText(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_PrimaryText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_SecondaryText(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_SecondaryText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_LightModeIconUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(13)
    def put_LightModeIconUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(14)
    def get_DarkModeIconUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(15)
    def put_DarkModeIconUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(16)
    def get_PrimaryTextColor(self) -> win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementTextColor: ...
    @winrt_commethod(17)
    def put_PrimaryTextColor(self, value: win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementTextColor) -> Void: ...
    @winrt_commethod(18)
    def get_SecondaryTextColor(self) -> win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementTextColor: ...
    @winrt_commethod(19)
    def put_SecondaryTextColor(self, value: win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementTextColor) -> Void: ...
    @winrt_commethod(20)
    def get_CustomAccessibilityText(self) -> WinRT_String: ...
    @winrt_commethod(21)
    def put_CustomAccessibilityText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(22)
    def get_IsSecondaryTextSubtle(self) -> Boolean: ...
    @winrt_commethod(23)
    def put_IsSecondaryTextSubtle(self, value: Boolean) -> Void: ...
    @winrt_commethod(24)
    def get_ShowBadgeIfUserNotEngaged(self) -> Boolean: ...
    @winrt_commethod(25)
    def put_ShowBadgeIfUserNotEngaged(self, value: Boolean) -> Void: ...
    @winrt_commethod(26)
    def get_ExpirationTime(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(27)
    def put_ExpirationTime(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(28)
    def get_Duration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(29)
    def put_Duration(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    CustomAccessibilityText = property(get_CustomAccessibilityText, put_CustomAccessibilityText)
    DarkModeIconUri = property(get_DarkModeIconUri, put_DarkModeIconUri)
    Duration = property(get_Duration, put_Duration)
    ExpirationTime = property(get_ExpirationTime, put_ExpirationTime)
    Id = property(get_Id, put_Id)
    IsSecondaryTextSubtle = property(get_IsSecondaryTextSubtle, put_IsSecondaryTextSubtle)
    LightModeIconUri = property(get_LightModeIconUri, put_LightModeIconUri)
    PrimaryText = property(get_PrimaryText, put_PrimaryText)
    PrimaryTextColor = property(get_PrimaryTextColor, put_PrimaryTextColor)
    SecondaryText = property(get_SecondaryText, put_SecondaryText)
    SecondaryTextColor = property(get_SecondaryTextColor, put_SecondaryTextColor)
    ShowBadgeIfUserNotEngaged = property(get_ShowBadgeIfUserNotEngaged, put_ShowBadgeIfUserNotEngaged)
class IFeedAnnouncementFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Notifications.IFeedAnnouncementFactory'
    _iid_ = Guid('{22074243-46d8-5af2-8715-1c76d1cb774c}')
    @winrt_commethod(6)
    def CreateInstance(self, id: WinRT_String, primaryText: WinRT_String, secondaryText: WinRT_String, lightModeIcon: win32more.Windows.Foundation.Uri, darkModeIcon: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.Widgets.Notifications.FeedAnnouncement: ...
class IFeedAnnouncementInvokedArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Notifications.IFeedAnnouncementInvokedArgs'
    _iid_ = Guid('{70a48d98-323d-5f19-a1e1-b63fe36edbf2}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_FeedDefinitionId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_AnnouncementId(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_ActionKind(self) -> win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementActionKind: ...
    ActionKind = property(get_ActionKind, None)
    AnnouncementId = property(get_AnnouncementId, None)
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Security.Credentials
import win32more.Windows.Win32.System.WinRT
class DeviceAccountAuthenticationType(Enum, Int32):
    Basic = 0
    OAuth = 1
    SingleSignOn = 2
class DeviceAccountConfiguration(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration
    _classid_ = 'Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountConfiguration'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountConfiguration.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountConfiguration: ...
    @winrt_mixinmethod
    def get_AccountName(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_AccountName(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_DeviceAccountTypeId(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DeviceAccountTypeId(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ServerType(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration) -> win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountServerType: ...
    @winrt_mixinmethod
    def put_ServerType(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration, value: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountServerType) -> Void: ...
    @winrt_mixinmethod
    def get_EmailAddress(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_EmailAddress(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Domain(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Domain(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_EmailSyncEnabled(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration) -> Boolean: ...
    @winrt_mixinmethod
    def put_EmailSyncEnabled(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ContactsSyncEnabled(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration) -> Boolean: ...
    @winrt_mixinmethod
    def put_ContactsSyncEnabled(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarSyncEnabled(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration) -> Boolean: ...
    @winrt_mixinmethod
    def put_CalendarSyncEnabled(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IncomingServerAddress(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_IncomingServerAddress(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IncomingServerPort(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def put_IncomingServerPort(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_IncomingServerRequiresSsl(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration) -> Boolean: ...
    @winrt_mixinmethod
    def put_IncomingServerRequiresSsl(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IncomingServerUsername(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_IncomingServerUsername(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_OutgoingServerAddress(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_OutgoingServerAddress(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_OutgoingServerPort(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def put_OutgoingServerPort(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_OutgoingServerRequiresSsl(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration) -> Boolean: ...
    @winrt_mixinmethod
    def put_OutgoingServerRequiresSsl(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_OutgoingServerUsername(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_OutgoingServerUsername(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IncomingServerCredential(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> win32more.Windows.Security.Credentials.PasswordCredential: ...
    @winrt_mixinmethod
    def put_IncomingServerCredential(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: win32more.Windows.Security.Credentials.PasswordCredential) -> Void: ...
    @winrt_mixinmethod
    def get_OutgoingServerCredential(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> win32more.Windows.Security.Credentials.PasswordCredential: ...
    @winrt_mixinmethod
    def put_OutgoingServerCredential(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: win32more.Windows.Security.Credentials.PasswordCredential) -> Void: ...
    @winrt_mixinmethod
    def get_OAuthRefreshToken(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_OAuthRefreshToken(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IsExternallyManaged(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsExternallyManaged(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AccountIconId(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountIconId: ...
    @winrt_mixinmethod
    def put_AccountIconId(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountIconId) -> Void: ...
    @winrt_mixinmethod
    def get_AuthenticationType(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountAuthenticationType: ...
    @winrt_mixinmethod
    def put_AuthenticationType(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountAuthenticationType) -> Void: ...
    @winrt_mixinmethod
    def get_IsSsoAuthenticationSupported(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> Boolean: ...
    @winrt_mixinmethod
    def get_SsoAccountId(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SsoAccountId(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_AlwaysDownloadFullMessage(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> Boolean: ...
    @winrt_mixinmethod
    def put_AlwaysDownloadFullMessage(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DoesPolicyAllowMailSync(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> Boolean: ...
    @winrt_mixinmethod
    def get_SyncScheduleKind(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountSyncScheduleKind: ...
    @winrt_mixinmethod
    def put_SyncScheduleKind(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountSyncScheduleKind) -> Void: ...
    @winrt_mixinmethod
    def get_MailAgeFilter(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountMailAgeFilter: ...
    @winrt_mixinmethod
    def put_MailAgeFilter(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountMailAgeFilter) -> Void: ...
    @winrt_mixinmethod
    def get_IsClientAuthenticationCertificateRequired(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsClientAuthenticationCertificateRequired(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AutoSelectAuthenticationCertificate(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> Boolean: ...
    @winrt_mixinmethod
    def put_AutoSelectAuthenticationCertificate(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AuthenticationCertificateId(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_AuthenticationCertificateId(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_CardDavSyncScheduleKind(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountSyncScheduleKind: ...
    @winrt_mixinmethod
    def put_CardDavSyncScheduleKind(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountSyncScheduleKind) -> Void: ...
    @winrt_mixinmethod
    def get_CalDavSyncScheduleKind(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountSyncScheduleKind: ...
    @winrt_mixinmethod
    def put_CalDavSyncScheduleKind(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountSyncScheduleKind) -> Void: ...
    @winrt_mixinmethod
    def get_CardDavServerUrl(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_CardDavServerUrl(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_CardDavRequiresSsl(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> Boolean: ...
    @winrt_mixinmethod
    def put_CardDavRequiresSsl(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CalDavServerUrl(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_CalDavServerUrl(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_CalDavRequiresSsl(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> Boolean: ...
    @winrt_mixinmethod
    def put_CalDavRequiresSsl(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_WasModifiedByUser(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> Boolean: ...
    @winrt_mixinmethod
    def put_WasModifiedByUser(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_WasIncomingServerCertificateHashConfirmed(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> Boolean: ...
    @winrt_mixinmethod
    def put_WasIncomingServerCertificateHashConfirmed(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IncomingServerCertificateHash(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_IncomingServerCertificateHash(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IsOutgoingServerAuthenticationRequired(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsOutgoingServerAuthenticationRequired(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsOutgoingServerAuthenticationEnabled(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsOutgoingServerAuthenticationEnabled(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_WasOutgoingServerCertificateHashConfirmed(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> Boolean: ...
    @winrt_mixinmethod
    def put_WasOutgoingServerCertificateHashConfirmed(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_OutgoingServerCertificateHash(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_OutgoingServerCertificateHash(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IsSyncScheduleManagedBySystem(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSyncScheduleManagedBySystem(self: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2, value: Boolean) -> Void: ...
    AccountIconId = property(get_AccountIconId, put_AccountIconId)
    AccountName = property(get_AccountName, put_AccountName)
    AlwaysDownloadFullMessage = property(get_AlwaysDownloadFullMessage, put_AlwaysDownloadFullMessage)
    AuthenticationCertificateId = property(get_AuthenticationCertificateId, put_AuthenticationCertificateId)
    AuthenticationType = property(get_AuthenticationType, put_AuthenticationType)
    AutoSelectAuthenticationCertificate = property(get_AutoSelectAuthenticationCertificate, put_AutoSelectAuthenticationCertificate)
    CalDavRequiresSsl = property(get_CalDavRequiresSsl, put_CalDavRequiresSsl)
    CalDavServerUrl = property(get_CalDavServerUrl, put_CalDavServerUrl)
    CalDavSyncScheduleKind = property(get_CalDavSyncScheduleKind, put_CalDavSyncScheduleKind)
    CalendarSyncEnabled = property(get_CalendarSyncEnabled, put_CalendarSyncEnabled)
    CardDavRequiresSsl = property(get_CardDavRequiresSsl, put_CardDavRequiresSsl)
    CardDavServerUrl = property(get_CardDavServerUrl, put_CardDavServerUrl)
    CardDavSyncScheduleKind = property(get_CardDavSyncScheduleKind, put_CardDavSyncScheduleKind)
    ContactsSyncEnabled = property(get_ContactsSyncEnabled, put_ContactsSyncEnabled)
    DeviceAccountTypeId = property(get_DeviceAccountTypeId, put_DeviceAccountTypeId)
    DoesPolicyAllowMailSync = property(get_DoesPolicyAllowMailSync, None)
    Domain = property(get_Domain, put_Domain)
    EmailAddress = property(get_EmailAddress, put_EmailAddress)
    EmailSyncEnabled = property(get_EmailSyncEnabled, put_EmailSyncEnabled)
    IncomingServerAddress = property(get_IncomingServerAddress, put_IncomingServerAddress)
    IncomingServerCertificateHash = property(get_IncomingServerCertificateHash, put_IncomingServerCertificateHash)
    IncomingServerCredential = property(get_IncomingServerCredential, put_IncomingServerCredential)
    IncomingServerPort = property(get_IncomingServerPort, put_IncomingServerPort)
    IncomingServerRequiresSsl = property(get_IncomingServerRequiresSsl, put_IncomingServerRequiresSsl)
    IncomingServerUsername = property(get_IncomingServerUsername, put_IncomingServerUsername)
    IsClientAuthenticationCertificateRequired = property(get_IsClientAuthenticationCertificateRequired, put_IsClientAuthenticationCertificateRequired)
    IsExternallyManaged = property(get_IsExternallyManaged, put_IsExternallyManaged)
    IsOutgoingServerAuthenticationEnabled = property(get_IsOutgoingServerAuthenticationEnabled, put_IsOutgoingServerAuthenticationEnabled)
    IsOutgoingServerAuthenticationRequired = property(get_IsOutgoingServerAuthenticationRequired, put_IsOutgoingServerAuthenticationRequired)
    IsSsoAuthenticationSupported = property(get_IsSsoAuthenticationSupported, None)
    IsSyncScheduleManagedBySystem = property(get_IsSyncScheduleManagedBySystem, put_IsSyncScheduleManagedBySystem)
    MailAgeFilter = property(get_MailAgeFilter, put_MailAgeFilter)
    OAuthRefreshToken = property(get_OAuthRefreshToken, put_OAuthRefreshToken)
    OutgoingServerAddress = property(get_OutgoingServerAddress, put_OutgoingServerAddress)
    OutgoingServerCertificateHash = property(get_OutgoingServerCertificateHash, put_OutgoingServerCertificateHash)
    OutgoingServerCredential = property(get_OutgoingServerCredential, put_OutgoingServerCredential)
    OutgoingServerPort = property(get_OutgoingServerPort, put_OutgoingServerPort)
    OutgoingServerRequiresSsl = property(get_OutgoingServerRequiresSsl, put_OutgoingServerRequiresSsl)
    OutgoingServerUsername = property(get_OutgoingServerUsername, put_OutgoingServerUsername)
    ServerType = property(get_ServerType, put_ServerType)
    SsoAccountId = property(get_SsoAccountId, put_SsoAccountId)
    SyncScheduleKind = property(get_SyncScheduleKind, put_SyncScheduleKind)
    WasIncomingServerCertificateHashConfirmed = property(get_WasIncomingServerCertificateHashConfirmed, put_WasIncomingServerCertificateHashConfirmed)
    WasModifiedByUser = property(get_WasModifiedByUser, put_WasModifiedByUser)
    WasOutgoingServerCertificateHashConfirmed = property(get_WasOutgoingServerCertificateHashConfirmed, put_WasOutgoingServerCertificateHashConfirmed)
class DeviceAccountIconId(Enum, Int32):
    Exchange = 0
    Msa = 1
    Outlook = 2
    Generic = 3
class DeviceAccountMailAgeFilter(Enum, Int32):
    All = 0
    Last1Day = 1
    Last3Days = 2
    Last7Days = 3
    Last14Days = 4
    Last30Days = 5
    Last90Days = 6
class DeviceAccountServerType(Enum, Int32):
    Exchange = 0
    Pop = 1
    Imap = 2
class DeviceAccountSyncScheduleKind(Enum, Int32):
    Manual = 0
    Every15Minutes = 1
    Every30Minutes = 2
    Every60Minutes = 3
    Every2Hours = 4
    Daily = 5
    AsItemsArrive = 6
class IDeviceAccountConfiguration(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration'
    _iid_ = Guid('{ad0123a3-fbdc-4d1b-be43-5a27ea4a1b63}')
    @winrt_commethod(6)
    def get_AccountName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_AccountName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_DeviceAccountTypeId(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_DeviceAccountTypeId(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_ServerType(self) -> win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountServerType: ...
    @winrt_commethod(11)
    def put_ServerType(self, value: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountServerType) -> Void: ...
    @winrt_commethod(12)
    def get_EmailAddress(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_EmailAddress(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_Domain(self) -> WinRT_String: ...
    @winrt_commethod(15)
    def put_Domain(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(16)
    def get_EmailSyncEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_EmailSyncEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_ContactsSyncEnabled(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_ContactsSyncEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_CalendarSyncEnabled(self) -> Boolean: ...
    @winrt_commethod(21)
    def put_CalendarSyncEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(22)
    def get_IncomingServerAddress(self) -> WinRT_String: ...
    @winrt_commethod(23)
    def put_IncomingServerAddress(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(24)
    def get_IncomingServerPort(self) -> Int32: ...
    @winrt_commethod(25)
    def put_IncomingServerPort(self, value: Int32) -> Void: ...
    @winrt_commethod(26)
    def get_IncomingServerRequiresSsl(self) -> Boolean: ...
    @winrt_commethod(27)
    def put_IncomingServerRequiresSsl(self, value: Boolean) -> Void: ...
    @winrt_commethod(28)
    def get_IncomingServerUsername(self) -> WinRT_String: ...
    @winrt_commethod(29)
    def put_IncomingServerUsername(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(30)
    def get_OutgoingServerAddress(self) -> WinRT_String: ...
    @winrt_commethod(31)
    def put_OutgoingServerAddress(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(32)
    def get_OutgoingServerPort(self) -> Int32: ...
    @winrt_commethod(33)
    def put_OutgoingServerPort(self, value: Int32) -> Void: ...
    @winrt_commethod(34)
    def get_OutgoingServerRequiresSsl(self) -> Boolean: ...
    @winrt_commethod(35)
    def put_OutgoingServerRequiresSsl(self, value: Boolean) -> Void: ...
    @winrt_commethod(36)
    def get_OutgoingServerUsername(self) -> WinRT_String: ...
    @winrt_commethod(37)
    def put_OutgoingServerUsername(self, value: WinRT_String) -> Void: ...
    AccountName = property(get_AccountName, put_AccountName)
    CalendarSyncEnabled = property(get_CalendarSyncEnabled, put_CalendarSyncEnabled)
    ContactsSyncEnabled = property(get_ContactsSyncEnabled, put_ContactsSyncEnabled)
    DeviceAccountTypeId = property(get_DeviceAccountTypeId, put_DeviceAccountTypeId)
    Domain = property(get_Domain, put_Domain)
    EmailAddress = property(get_EmailAddress, put_EmailAddress)
    EmailSyncEnabled = property(get_EmailSyncEnabled, put_EmailSyncEnabled)
    IncomingServerAddress = property(get_IncomingServerAddress, put_IncomingServerAddress)
    IncomingServerPort = property(get_IncomingServerPort, put_IncomingServerPort)
    IncomingServerRequiresSsl = property(get_IncomingServerRequiresSsl, put_IncomingServerRequiresSsl)
    IncomingServerUsername = property(get_IncomingServerUsername, put_IncomingServerUsername)
    OutgoingServerAddress = property(get_OutgoingServerAddress, put_OutgoingServerAddress)
    OutgoingServerPort = property(get_OutgoingServerPort, put_OutgoingServerPort)
    OutgoingServerRequiresSsl = property(get_OutgoingServerRequiresSsl, put_OutgoingServerRequiresSsl)
    OutgoingServerUsername = property(get_OutgoingServerUsername, put_OutgoingServerUsername)
    ServerType = property(get_ServerType, put_ServerType)
class IDeviceAccountConfiguration2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataAccounts.SystemAccess.IDeviceAccountConfiguration2'
    _iid_ = Guid('{f2b2e5a6-728d-4a4a-8945-2bf8580136de}')
    @winrt_commethod(6)
    def get_IncomingServerCredential(self) -> win32more.Windows.Security.Credentials.PasswordCredential: ...
    @winrt_commethod(7)
    def put_IncomingServerCredential(self, value: win32more.Windows.Security.Credentials.PasswordCredential) -> Void: ...
    @winrt_commethod(8)
    def get_OutgoingServerCredential(self) -> win32more.Windows.Security.Credentials.PasswordCredential: ...
    @winrt_commethod(9)
    def put_OutgoingServerCredential(self, value: win32more.Windows.Security.Credentials.PasswordCredential) -> Void: ...
    @winrt_commethod(10)
    def get_OAuthRefreshToken(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_OAuthRefreshToken(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_IsExternallyManaged(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsExternallyManaged(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_AccountIconId(self) -> win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountIconId: ...
    @winrt_commethod(15)
    def put_AccountIconId(self, value: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountIconId) -> Void: ...
    @winrt_commethod(16)
    def get_AuthenticationType(self) -> win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountAuthenticationType: ...
    @winrt_commethod(17)
    def put_AuthenticationType(self, value: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountAuthenticationType) -> Void: ...
    @winrt_commethod(18)
    def get_IsSsoAuthenticationSupported(self) -> Boolean: ...
    @winrt_commethod(19)
    def get_SsoAccountId(self) -> WinRT_String: ...
    @winrt_commethod(20)
    def put_SsoAccountId(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(21)
    def get_AlwaysDownloadFullMessage(self) -> Boolean: ...
    @winrt_commethod(22)
    def put_AlwaysDownloadFullMessage(self, value: Boolean) -> Void: ...
    @winrt_commethod(23)
    def get_DoesPolicyAllowMailSync(self) -> Boolean: ...
    @winrt_commethod(24)
    def get_SyncScheduleKind(self) -> win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountSyncScheduleKind: ...
    @winrt_commethod(25)
    def put_SyncScheduleKind(self, value: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountSyncScheduleKind) -> Void: ...
    @winrt_commethod(26)
    def get_MailAgeFilter(self) -> win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountMailAgeFilter: ...
    @winrt_commethod(27)
    def put_MailAgeFilter(self, value: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountMailAgeFilter) -> Void: ...
    @winrt_commethod(28)
    def get_IsClientAuthenticationCertificateRequired(self) -> Boolean: ...
    @winrt_commethod(29)
    def put_IsClientAuthenticationCertificateRequired(self, value: Boolean) -> Void: ...
    @winrt_commethod(30)
    def get_AutoSelectAuthenticationCertificate(self) -> Boolean: ...
    @winrt_commethod(31)
    def put_AutoSelectAuthenticationCertificate(self, value: Boolean) -> Void: ...
    @winrt_commethod(32)
    def get_AuthenticationCertificateId(self) -> WinRT_String: ...
    @winrt_commethod(33)
    def put_AuthenticationCertificateId(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(34)
    def get_CardDavSyncScheduleKind(self) -> win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountSyncScheduleKind: ...
    @winrt_commethod(35)
    def put_CardDavSyncScheduleKind(self, value: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountSyncScheduleKind) -> Void: ...
    @winrt_commethod(36)
    def get_CalDavSyncScheduleKind(self) -> win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountSyncScheduleKind: ...
    @winrt_commethod(37)
    def put_CalDavSyncScheduleKind(self, value: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountSyncScheduleKind) -> Void: ...
    @winrt_commethod(38)
    def get_CardDavServerUrl(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(39)
    def put_CardDavServerUrl(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(40)
    def get_CardDavRequiresSsl(self) -> Boolean: ...
    @winrt_commethod(41)
    def put_CardDavRequiresSsl(self, value: Boolean) -> Void: ...
    @winrt_commethod(42)
    def get_CalDavServerUrl(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(43)
    def put_CalDavServerUrl(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(44)
    def get_CalDavRequiresSsl(self) -> Boolean: ...
    @winrt_commethod(45)
    def put_CalDavRequiresSsl(self, value: Boolean) -> Void: ...
    @winrt_commethod(46)
    def get_WasModifiedByUser(self) -> Boolean: ...
    @winrt_commethod(47)
    def put_WasModifiedByUser(self, value: Boolean) -> Void: ...
    @winrt_commethod(48)
    def get_WasIncomingServerCertificateHashConfirmed(self) -> Boolean: ...
    @winrt_commethod(49)
    def put_WasIncomingServerCertificateHashConfirmed(self, value: Boolean) -> Void: ...
    @winrt_commethod(50)
    def get_IncomingServerCertificateHash(self) -> WinRT_String: ...
    @winrt_commethod(51)
    def put_IncomingServerCertificateHash(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(52)
    def get_IsOutgoingServerAuthenticationRequired(self) -> Boolean: ...
    @winrt_commethod(53)
    def put_IsOutgoingServerAuthenticationRequired(self, value: Boolean) -> Void: ...
    @winrt_commethod(54)
    def get_IsOutgoingServerAuthenticationEnabled(self) -> Boolean: ...
    @winrt_commethod(55)
    def put_IsOutgoingServerAuthenticationEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(56)
    def get_WasOutgoingServerCertificateHashConfirmed(self) -> Boolean: ...
    @winrt_commethod(57)
    def put_WasOutgoingServerCertificateHashConfirmed(self, value: Boolean) -> Void: ...
    @winrt_commethod(58)
    def get_OutgoingServerCertificateHash(self) -> WinRT_String: ...
    @winrt_commethod(59)
    def put_OutgoingServerCertificateHash(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(60)
    def get_IsSyncScheduleManagedBySystem(self) -> Boolean: ...
    @winrt_commethod(61)
    def put_IsSyncScheduleManagedBySystem(self, value: Boolean) -> Void: ...
    AccountIconId = property(get_AccountIconId, put_AccountIconId)
    AlwaysDownloadFullMessage = property(get_AlwaysDownloadFullMessage, put_AlwaysDownloadFullMessage)
    AuthenticationCertificateId = property(get_AuthenticationCertificateId, put_AuthenticationCertificateId)
    AuthenticationType = property(get_AuthenticationType, put_AuthenticationType)
    AutoSelectAuthenticationCertificate = property(get_AutoSelectAuthenticationCertificate, put_AutoSelectAuthenticationCertificate)
    CalDavRequiresSsl = property(get_CalDavRequiresSsl, put_CalDavRequiresSsl)
    CalDavServerUrl = property(get_CalDavServerUrl, put_CalDavServerUrl)
    CalDavSyncScheduleKind = property(get_CalDavSyncScheduleKind, put_CalDavSyncScheduleKind)
    CardDavRequiresSsl = property(get_CardDavRequiresSsl, put_CardDavRequiresSsl)
    CardDavServerUrl = property(get_CardDavServerUrl, put_CardDavServerUrl)
    CardDavSyncScheduleKind = property(get_CardDavSyncScheduleKind, put_CardDavSyncScheduleKind)
    DoesPolicyAllowMailSync = property(get_DoesPolicyAllowMailSync, None)
    IncomingServerCertificateHash = property(get_IncomingServerCertificateHash, put_IncomingServerCertificateHash)
    IncomingServerCredential = property(get_IncomingServerCredential, put_IncomingServerCredential)
    IsClientAuthenticationCertificateRequired = property(get_IsClientAuthenticationCertificateRequired, put_IsClientAuthenticationCertificateRequired)
    IsExternallyManaged = property(get_IsExternallyManaged, put_IsExternallyManaged)
    IsOutgoingServerAuthenticationEnabled = property(get_IsOutgoingServerAuthenticationEnabled, put_IsOutgoingServerAuthenticationEnabled)
    IsOutgoingServerAuthenticationRequired = property(get_IsOutgoingServerAuthenticationRequired, put_IsOutgoingServerAuthenticationRequired)
    IsSsoAuthenticationSupported = property(get_IsSsoAuthenticationSupported, None)
    IsSyncScheduleManagedBySystem = property(get_IsSyncScheduleManagedBySystem, put_IsSyncScheduleManagedBySystem)
    MailAgeFilter = property(get_MailAgeFilter, put_MailAgeFilter)
    OAuthRefreshToken = property(get_OAuthRefreshToken, put_OAuthRefreshToken)
    OutgoingServerCertificateHash = property(get_OutgoingServerCertificateHash, put_OutgoingServerCertificateHash)
    OutgoingServerCredential = property(get_OutgoingServerCredential, put_OutgoingServerCredential)
    SsoAccountId = property(get_SsoAccountId, put_SsoAccountId)
    SyncScheduleKind = property(get_SyncScheduleKind, put_SyncScheduleKind)
    WasIncomingServerCertificateHashConfirmed = property(get_WasIncomingServerCertificateHashConfirmed, put_WasIncomingServerCertificateHashConfirmed)
    WasModifiedByUser = property(get_WasModifiedByUser, put_WasModifiedByUser)
    WasOutgoingServerCertificateHashConfirmed = property(get_WasOutgoingServerCertificateHashConfirmed, put_WasOutgoingServerCertificateHashConfirmed)
class IUserDataAccountSystemAccessManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataAccounts.SystemAccess.IUserDataAccountSystemAccessManagerStatics'
    _iid_ = Guid('{9d6b11b9-cbe5-45f5-822b-c267b81dbdb6}')
    @winrt_commethod(6)
    def AddAndShowDeviceAccountsAsync(self, accounts: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountConfiguration]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
class IUserDataAccountSystemAccessManagerStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataAccounts.SystemAccess.IUserDataAccountSystemAccessManagerStatics2'
    _iid_ = Guid('{943f854d-4b4e-439f-83d3-979b27c05ac7}')
    @winrt_commethod(6)
    def SuppressLocalAccountWithAccountAsync(self, userDataAccountId: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def CreateDeviceAccountAsync(self, account: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountConfiguration) -> win32more.Windows.Foundation.IAsyncOperation[WinRT_String]: ...
    @winrt_commethod(8)
    def DeleteDeviceAccountAsync(self, accountId: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(9)
    def GetDeviceAccountConfigurationAsync(self, accountId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountConfiguration]: ...
class UserDataAccountSystemAccessManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataAccounts.SystemAccess.UserDataAccountSystemAccessManager'
    @winrt_classmethod
    def SuppressLocalAccountWithAccountAsync(cls: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IUserDataAccountSystemAccessManagerStatics2, userDataAccountId: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def CreateDeviceAccountAsync(cls: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IUserDataAccountSystemAccessManagerStatics2, account: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountConfiguration) -> win32more.Windows.Foundation.IAsyncOperation[WinRT_String]: ...
    @winrt_classmethod
    def DeleteDeviceAccountAsync(cls: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IUserDataAccountSystemAccessManagerStatics2, accountId: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def GetDeviceAccountConfigurationAsync(cls: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IUserDataAccountSystemAccessManagerStatics2, accountId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountConfiguration]: ...
    @winrt_classmethod
    def AddAndShowDeviceAccountsAsync(cls: win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.IUserDataAccountSystemAccessManagerStatics, accounts: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.UserDataAccounts.SystemAccess.DeviceAccountConfiguration]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...


make_ready(__name__)
